import { LarkServer } from "../../types"
import LarkBaseService from "./base"

class LarkChatService extends LarkBaseService {
  /**
   * 获取机器人所在群列表
   */
  async getInnerList() {
    const path = "/im/v1/chats"
    const chatList = []
    let hasMore = true
    let pageToken = ""
    while (hasMore) {
      const { data, code } = await this.get<
        LarkServer.BaseListRes<LarkServer.ChatGroupData>
      >(path, {
        page_size: 100,
        page_token: pageToken,
      })
      if (code !== 0) break
      chatList.push(...data.items)
      hasMore = data.has_more
      pageToken = data.page_token
    }
    return {
      code: 0,
      data: chatList,
      message: "ok",
    }
  }

  /**
   * 获取群聊信息
   * @param chatId 群聊ID
   */
  async getChatInfo(chatId: string) {
    const path = `/im/v1/chats/${chatId}`
    return this.get<LarkServer.BaseRes<LarkServer.ChatGroupData>>(path)
  }
}

export default LarkChatService
